@@ -1,10 +1,27 @@
 import os
+import sys
 import unittest
 from subprocess import Popen, PIPE
 from tempfile import mkstemp
+
+import sys
+sys.path.insert(0,
+                os.path.split(os.path.abspath(os.path.dirname(__file__)))[0])
 import autopep8
 
 
+def py27_and_above(func):
+    if sys.version_info[0] == 2 and sys.version_info[1] < 7:
+        func = None
+    return func
+
+
+def only_py2(func):
+    if sys.version_info[0] != 2:
+        func = None
+    return func
+
+
 class TestUtils(unittest.TestCase):
 
     def test_find_newline_only_cr(self):
@@ -36,13 +53,15 @@ class TestFixPEP8Error(unittest.TestCase):
     def tearDown(self):
         os.remove(self.tempfile[1])
 
-    def _inner_setup(self, line):
+    def _inner_setup(self, line, options=""):
         f = open(self.tempfile[1], 'w')
         f.write(line)
         f.close()
         root_dir = os.path.split(os.path.abspath(os.path.dirname(__file__)))[0]
-        p = Popen([os.path.join(root_dir, 'autopep8.py'),
-                   self.tempfile[1]], stdout=PIPE)
+        cmd = [os.path.join(root_dir, 'autopep8.py')]
+        cmd.extend(options.split())
+        cmd.append(self.tempfile[1])
+        p = Popen(cmd, stdout=PIPE)
         self.result = p.communicate()[0].decode('utf8')
 
     def test_e111_short(self):
@@ -143,6 +162,30 @@ while True:
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    def test_e241(self):
+        line = "l = (1,  2)\n"
+        fixed = "l = (1, 2)\n"
+        self._inner_setup(line, "--ignore W")
+        self.assertEqual(self.result, fixed)
+
+    def test_e241_double(self):
+        line = "l = (1,   2)\n"
+        fixed = "l = (1, 2)\n"
+        self._inner_setup(line, "--ignore W")
+        self.assertEqual(self.result, fixed)
+
+    def test_e242(self):
+        line = "l = (1,\t2)\n"
+        fixed = "l = (1, 2)\n"
+        self._inner_setup(line, "--ignore W")
+        self.assertEqual(self.result, fixed)
+
+    def test_e242_double(self):
+        line = "l = (1,\t\t2)\n"
+        fixed = "l = (1, 2)\n"
+        self._inner_setup(line, "--ignore W")
+        self.assertEqual(self.result, fixed)
+
     def test_e251(self):
         line = "def a(arg = 1):\n    print arg\n"
         fixed = "def a(arg=1):\n    print arg\n"
@@ -341,94 +384,110 @@ class TestFixPEP8Warning(unittest.TestCase):
         self._inner_setup(line)
         self.assertEqual(self.result, line)
 
+    @only_py2
     def test_w602_arg_is_string(self):
         line = "raise ValueError, \"w602 test\"\n"
         fixed = "raise ValueError(\"w602 test\")\n"
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    @only_py2
     def test_w602_arg_is_string_with_comment(self):
         line = "raise ValueError, \"w602 test\"  # comment\n"
         fixed = "raise ValueError(\"w602 test\")  # comment\n"
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    @only_py2
     def test_w602_skip_ambiguous_case(self):
         line = "raise 'a', 'b', 'c'\n"
         self._inner_setup(line)
         self.assertEqual(self.result, line)
 
+    @only_py2
     def test_w602_triple_quotes(self):
         line = 'raise ValueError, """hello"""\n1\n'
         fixed = 'raise ValueError("""hello""")\n1\n'
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    @only_py2
     def test_w602_multiline(self):
         line = 'raise ValueError, """\nhello"""\n'
         fixed = 'raise ValueError("""\nhello""")\n'
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    @only_py2
     def test_w602_skip_complex_multiline(self):
         # We do not handle formatted multiline strings
         line = 'raise ValueError, """\nhello %s %s""" % (1,\n2)\n'
         self._inner_setup(line)
         self.assertEqual(self.result, line)
 
+    @only_py2
     def test_w602_multiline_with_trailing_spaces(self):
         line = 'raise ValueError, """\nhello"""    \n'
         fixed = 'raise ValueError("""\nhello""")\n'
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    @only_py2
     def test_w602_multiline_with_escaped_newline(self):
         line = 'raise ValueError, \\\n"""\nhello"""\n'
         fixed = 'raise ValueError("""\nhello""")\n'
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    @only_py2
     def test_w602_multiline_with_escaped_newline_and_comment(self):
         line = 'raise ValueError, \\\n"""\nhello"""  # comment\n'
         fixed = 'raise ValueError("""\nhello""")  # comment\n'
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    @only_py2
     def test_w602_multiline_with_multiple_escaped_newlines(self):
         line = 'raise ValueError, \\\n\\\n\\\n"""\nhello"""\n'
         fixed = 'raise ValueError("""\nhello""")\n'
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    @only_py2
     def test_w602_multiline_with_nested_quotes(self):
         line = 'raise ValueError, """hello\'\'\'blah"a"b"c"""\n'
         fixed = 'raise ValueError("""hello\'\'\'blah"a"b"c""")\n'
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    @only_py2
     def test_w602_skip_multiline_with_single_quotes(self):
         line = "raise ValueError, '''\nhello'''\n"
         fixed = "raise ValueError('''\nhello''')\n"
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    @only_py2
     def test_w602_multiline_string_stays_the_same(self):
         line = 'raise """\nhello"""\n'
         self._inner_setup(line)
         self.assertEqual(self.result, line)
 
+    @only_py2
     def test_w602_escaped_lf(self):
         line = 'raise ValueError, \\\n"hello"\n'
         fixed = 'raise ValueError("hello")\n'
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    @only_py2
     def test_w602_escaped_crlf(self):
         line = 'raise ValueError, \\\r\n"hello"\n'
         fixed = 'raise ValueError("hello")\n'
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    @only_py2
     def test_w602_indentation(self):
         line = 'def foo():\n    raise ValueError, "hello"\n'
         fixed = 'def foo():\n    raise ValueError("hello")\n'
@@ -442,24 +501,34 @@ class TestFixPEP8Warning(unittest.TestCase):
     #    self._inner_setup(line)
     #    self.assertEqual(self.result, fixed)
 
+    @only_py2
     def test_w602_multiple_statements(self):
         line = 'raise ValueError, "hello";print 1\n'
         fixed = 'raise ValueError("hello")\nprint 1\n'
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    @only_py2
     def test_w602_raise_argument_triple(self):
         line = 'raise ValueError, "info", traceback\n'
         fixed = 'raise ValueError("info"), None, traceback\n'
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    @only_py2
     def test_w602_raise_argument_triple_with_comment(self):
         line = 'raise ValueError, "info", traceback  # comment\n'
         fixed = 'raise ValueError("info"), None, traceback  # comment\n'
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    @only_py2
+    def test_w602_raise_argument_triple_fake(self):
+        line = 'raise ValueError, "info, info2"\n'
+        fixed = 'raise ValueError("info, info2")\n'
+        self._inner_setup(line)
+        self.assertEqual(self.result, fixed)
+
     def test_w603(self):
         line = "if 2 <> 2:\n    print False"
         fixed = "if 2 != 2:\n    print False\n"
@@ -509,12 +578,14 @@ class TestOptions(unittest.TestCase):
         self._inner_setup(line, ['--pep8-passes', '0'])
         self.assertEqual(self.result, fixed)
 
+    @py27_and_above
     def test_no_arguments(self):
         root_dir = os.path.split(os.path.abspath(os.path.dirname(__file__)))[0]
         p = Popen([os.path.join(root_dir, 'autopep8.py')],
                   stdout=PIPE)
         self.assertIn('Usage:', p.communicate()[0].decode('utf8'))
 
+    @py27_and_above
     def test_verbose(self):
         line = '"' + 80 * 'a' + '"'
         f = open(self.tempfile[1], 'w')
@@ -541,7 +612,7 @@ class TestOptions(unittest.TestCase):
         p.wait()
 
         f = open(self.tempfile[1])
-        self.assertEquals(f.read(), fixed)
+        self.assertEqual(f.read(), fixed)
         f.close()
 
 if __name__ == '__main__':
